django-thermometer
==================

Django app which publishes as REST API the figures that come out from sensor DS18B20. The sensor can be
bought at Adrafruit.


Further documentation found at http://jpardobl.com/home-automation-python-project/
